<?php
/**
 * Plugin Name: Podeli payment
 * Description: Podeli Payments Gateway for WooCommerce
 * Version: 1.0.13
 * Author: Подели
 * Author URI: https://podeli.ru
 * Copyright: © 2025, CODD.
 * Text Domain: podeli_payment
 */

class WC_Podelipayment
{
    private $settings;

    public function __construct()
    {
        $this->settings = get_option('woocommerce_podelipayment_settings');

        if (empty($this->settings['login'])) {
            $this->settings['login'] = '';
        }
        if (empty($this->settings['password'])) {
            $this->settings['password'] = '';
        }

        if (empty($this->settings['enabled'])) {
            $this->settings['enabled'] = 'no';
        }

        add_action('plugins_loaded', [$this, 'initGateway']);
    }

    public function initGateway()
    {
        if (!class_exists('WC_Payment_Gateway')) {
            return;
        }

        load_plugin_textdomain('podeli_payment', false, dirname(plugin_basename(__FILE__)) . '/languages/');

        include_once __DIR__ . '/includes/class-wc-gateway-podelipayment.php';

        add_filter('woocommerce_payment_gateways', [$this, 'addGateway']);

        if ($this->settings['enabled'] == 'no') {
            return;
        }

        // Disable for subscriptions until supported
        if (!is_admin() && class_exists('WC_Subscriptions_Cart') && WC_Subscriptions_Cart::cart_contains_subscription() && 'no' === get_option(WC_Subscriptions_Admin::$option_prefix . '_accept_manual_renewals', 'no')) {
            return;
        }

    }

    public function addGateway($methods)
    {
        $methods[] = 'WC_Gateway_podelipayment';
        return $methods;
    }
}
$GLOBALS['wc_podelipayment'] = new WC_Podelipayment();